@@ -3,9 +3,6 @@ class ControlContext:
         self.deck_context = deck_context
         self.key_no = key_no
 
-    def set_icon(self, icon_filename):
-        self.deck_context.set_icon(self.key_no, icon_filename)
-
     def set_icon_native(self, icon):
         self.deck_context.set_key_image_native(self.key_no, icon)
 
